@@ -5,8 +5,14 @@ use utf8;
 use base qw/Exporter/;
 use Web::Scraper;
 use URI;
+BEGIN {
+    eval q{
+        use HTML::TreeBuilder::LibXML;
+        HTML::TreeBuilder::LibXML->replace_original();
+    };
+}
 
-our @EXPORT = qw(parse_one scraper process col as_tree);
+our @EXPORT = qw(parse_one scraper process col as_tree result);
 
 sub import {
     my $class = shift;
@@ -31,7 +37,8 @@ sub parse_one {
 
     *{"$pkg\::scrape"} = sub {
         my @res = ();
-        for my $url (@{ $args{urls} }) {
+        my $urls = $args{urls} or die "missing urls";
+        for my $url ( @$urls ) {
             my $result = scraper {
                 process $args{xpath}, 'rows[]', $args{scraper};
             }->scrape( URI->new($url) )->{rows};
